from __future__ import annotations
from fastapi import FastAPI
import jwt.algorithms
import jwt
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.backends import default_backend
from functools import cache
import os
from api_server.jwks_schema import ResponseJwks, ResponseRsaJwk
import time

app = FastAPI()


@app.get("/")
async def root():
    return {"message": "Hello World"}


@app.get("/some_protected_endpoint")
async def protected_endpoint():
    # TODO: Read X-Apigateway-Api-Userinfo header
    return {"message": "You reached the protected endpoint"}


@app.get("/get_short_lived_token")
async def get_short_lived_token():
    gateway_address = os.environ["JWT_GATEWAY_ADDRESS"]
    client_id = os.environ["JWT_CLIENT_ID"]
    jwt_private_key = os.environ["JWT_PRIVATE_KEY"]
    private_key = serialization.load_pem_private_key(
        jwt_private_key.encode("utf-8"), password=None, backend=default_backend()
    )
    encoded = jwt.encode(
        {
            "iss": "issuer of the token",
            "sub": "Alice",
            "aud": client_id,
            "iat": int(time.time()),
            "exp": int(time.time()) + 5 * 60,
        },
        private_key,
        algorithm="RS256",
    )

    return {"message": "This JWT will only last 5 minutes.", "token": encoded}


@app.get("/.well-known/jwks.json")
async def jwks() -> ResponseJwks:
    return _generate_jwks()


@cache
def _generate_jwks() -> ResponseJwks:
    private_key_pem = os.environ["JWT_PRIVATE_KEY"]
    private_key = serialization.load_pem_private_key(
        private_key_pem.encode("utf-8"), password=None, backend=default_backend()
    )
    jwk_json = jwt.algorithms.RSAAlgorithm.to_jwk(private_key)
    return ResponseJwks(keys=[ResponseRsaJwk.model_validate_json(jwk_json)])
